@@ -1,9 +1,12 @@
+import json
 import logging
+import math
 import os
 import time
 from datetime import timedelta
 
 import feedparser
+from appdirs import user_cache_dir
 from dateutil import parser
 
 from .ProjectHolder import ProjectHolder
@@ -11,6 +14,9 @@ from .utils import ApiCredentialsError, BadProjectError
 
 log = logging.getLogger(__name__)
 
+TOKEN_PRO_TIP = 'ProTip: set GITHUB_API_TOKEN env var as per ' \
+                'https://github.com/dvershinin/lastversion#tips'
+
 
 class GitHubRepoSession(ProjectHolder):
     DEFAULT_HOSTNAME = 'github.com'
@@ -39,8 +45,61 @@ class GitHubRepoSession(ProjectHolder):
     RELEASE_URL_FORMAT = "https://{hostname}/{repo}/archive/{tag}/{name}-{tag}.{ext}"
     SHORT_RELEASE_URL_FORMAT = "https://{hostname}/{repo}/archive/{tag}.{ext}"
 
+    def find_repo_by_name_only(self, repo):
+        if repo.startswith(('https://', 'http://')):
+            return None
+        cache_repo_names_file = "{}/repos.json".format(user_cache_dir("lastversion"))
+        try:
+            with open(cache_repo_names_file, 'r') as reader:
+                cache = json.load(reader)
+        except (IOError, ValueError):
+            cache = {}
+        try:
+            if repo in cache and time.time() - cache[repo]['updated_at'] < 3600 * 24 * 30:
+                log.info("Found {} in repo short name cache".format(repo))
+                if not cache[repo]['repo']:
+                    raise BadProjectError(
+                        'No project found on GitHub for search query: {}'.format(repo)
+                    )
+                return cache[repo]['repo']
+        except TypeError:
+            pass
+        log.info("Making query against GitHub API to search repo {}".format(repo))
+        r = self.get(
+            '{}/search/repositories?q={}+in:name'.format(self.api_base, repo))
+        if r.status_code == 404:
+            # when not found, skip using this holder in the factory by not setting self.repo
+            return None
+        if r.status_code != 200:
+            raise BadProjectError(
+                'Error while identifying full repository on GitHub for search query: {}'.format(
+                    repo
+                )
+            )
+        data = r.json()
+        full_name = ''
+        if data['items']:
+            full_name = data['items'][0]['full_name']
+        cache[repo] = {
+            'repo': full_name,
+            'updated_at': int(time.time())
+        }
+        try:
+            with open(cache_repo_names_file, 'w') as writer:
+                writer.write(
+                    json.dumps(cache)
+                )
+        except (IOError, ValueError):
+            pass
+        if not full_name:
+            raise BadProjectError(
+                'No project found on GitHub for search query: {}'.format(repo)
+            )
+        return full_name
+
     def __init__(self, repo, hostname):
         super(GitHubRepoSession, self).__init__()
+        self.rate_limited_count = 0
         self.api_token = os.getenv("GITHUB_API_TOKEN")
         self.hostname = hostname
         if not self.hostname:
@@ -57,20 +116,13 @@ class GitHubRepoSession(ProjectHolder):
         else:
             self.api_base = 'https://api.{}'.format(self.DEFAULT_HOSTNAME)
         if '/' not in repo:
-            r = self.get(
-                '{}/search/repositories?q={}+in:name'.format(self.api_base, repo))
-            if r.status_code != 200:
+            repo = self.find_repo_by_name_only(repo)
+            if not repo:
                 return
-            data = r.json()
-            if not data['items']:
-                raise BadProjectError(
-                    'No project found on GitHub for search query: {}'.format(repo)
-                )
-            self.set_repo(data['items'][0]['full_name'])
+            self.set_repo(repo)
             log.info('Using repo {} obtained from search API'.format(self.repo))
         else:
             self.set_repo(repo)
-        self.rate_limited_count = 0
 
     def get_rate_limit_url(self):
         return '{}/rate_limit'.format(self.api_base)
@@ -91,7 +143,9 @@ class GitHubRepoSession(ProjectHolder):
                             self.rate_limited_count)
                     )
                 remaining = int(r.headers['X-RateLimit-Remaining'])
-                wait_for = int(r.headers['X-RateLimit-Reset']) - time.time()
+                # 1 sec to account for skewed clock between GitHub and client
+                wait_for = float(r.headers['X-RateLimit-Reset']) - time.time() + 1.0
+                wait_for = math.ceil(wait_for)
                 if not remaining:
                     # got 403, likely due to used quota
                     if wait_for < 300:
@@ -101,9 +155,10 @@ class GitHubRepoSession(ProjectHolder):
                                 'be reinstated'
                             )
                         else:
-                            log.warning(
-                                'Waiting {} seconds for API quota reinstatement'.format(wait_for)
-                            )
+                            w = 'Waiting {} seconds for API quota reinstatement.'.format(wait_for)
+                            if "GITHUB_API_TOKEN" not in os.environ:
+                                w = "{} {}".format(w, TOKEN_PRO_TIP)
+                            log.warning(w)
                             time.sleep(wait_for)
                         self.rate_limited_count = self.rate_limited_count + 1
                         return self.get(url)
